Struct google_appengine1_beta5::ContainerInfo [−][src]
Docker image that is used to create a container and start a VM instance for the version that you deploy. Only applicable for instances running in the App Engine flexible environment.
This type is not used in any activity, and only used as part of another schema.
Fields
image: Option<String>
URI to the hosted container image in Google Container Registry. The URI must be fully qualified and include a tag or digest. Examples: "gcr.io/my-project/image:tag" or "gcr.io/my-project/image@digest"