Struct google_appengine1_beta5::ScriptHandler [−][src]
Executes a script to handle the request that matches the URL pattern.
This type is not used in any activity, and only used as part of another schema.
Fields
script_path: Option<String>
Path to the script from the application root directory.